import {
  Button,
  TextField,
  Box,
  Autocomplete,
  Typography,
} from "@mui/material";
import {
  BackButton,
  sightsStore,
  TabPanel,
  languageStore,
  CreateSight,
  Language,
  cityStore,
  CoordinatesInput,
} from "@shared";
import { LanguageSwitcher } from "@widgets";

import { observer } from "mobx-react-lite";
import { useState } from "react";

// Мокап для всплывающей подсказки

export const InformationTab = observer(
  ({ value, index }: { value: number; index: number }) => {
    const { cities } = cityStore;
    const { createSight, updateCreateSight, createSightAction } = sightsStore;
    const [city, setCity] = useState<number>(0);
    const [coordinates, setCoordinates] = useState({
      latitude: 0,
      longitude: 0,
    });
    const { language } = languageStore;

    const handleChange = (
      language: Language,
      content: Partial<CreateSight[Language]>
    ) => {
      updateCreateSight(language, content);
    };

    const handleSave = async () => {
      try {
        await createSightAction(createSight[language], city, coordinates);
      } catch (error) {
        console.error(error);
      }
    };

    return (
      <TabPanel value={value} index={index}>
        <Box
          sx={{
            display: "flex",
            flexDirection: "column",
            gap: 3,
            position: "relative",
            paddingBottom: "70px" /* Space for save button */,
          }}
        >
          <BackButton />

          <Box
            sx={{
              display: "flex",

              gap: 4, // Added gap between the two main columns
              width: "100%",
              flexDirection: "column",
            }}
          >
            {/* Left column with main fields */}
            <Box
              sx={{
                flexGrow: 1,
                display: "flex",
                width: "80%",
                flexDirection: "column",
                gap: 2.5,
              }}
            >
              <TextField
                label={`Название (${language.toUpperCase()})`}
                value={createSight[language]?.name ?? ""}
                onChange={(e) => {
                  handleChange(language as Language, {
                    name: e.target.value,
                  });
                }}
                fullWidth
                variant="outlined"
              />
              <TextField
                label={`Описание (${language.toUpperCase()})`}
                value={createSight?.[language]?.description ?? ""}
                onChange={(e) => {
                  handleChange(language as Language, {
                    description: e.target.value,
                  });
                }}
                fullWidth
                variant="outlined"
                multiline
                rows={4}
              />
              <TextField
                label="Адрес"
                value={createSight?.[language]?.address ?? ""}
                onChange={(e) => {
                  handleChange(language as Language, {
                    address: e.target.value,
                  });
                }}
                fullWidth
                variant="outlined"
              />
              <Autocomplete
                options={cities}
                getOptionLabel={(option) => option.name}
                onChange={(_, value) => {
                  setCity(value?.id ?? 0);
                }}
                renderInput={(params) => (
                  <TextField {...params} label="Город" />
                )}
              />

              <CoordinatesInput setValue={setCoordinates} />
            </Box>

            {/* Правая колонка для логотипа и водяных знаков
            <Box
              sx={{
                display: "flex",

                gap: 4,
              }}
            >

              <Box
                sx={{
                  display: "flex",
                  justifyContent: "space-around",
                  width: "80%",
                  gap: 2,
                  flexDirection: { xs: "column", sm: "row" }, // Stack on extra small, side-by-side on small and up
                }}
              >
                <Paper
                  elevation={2}
                  sx={{
                    padding: 2,
                    display: "flex",
                    flexDirection: "column",
                    alignItems: "center",
                    gap: 1,
                    flex: 1,
                    minWidth: 150, // Ensure a minimum width
                  }}
                >
                  <Box sx={{ display: "flex", alignItems: "center" }}>
                    <Typography
                      variant="subtitle2"
                      gutterBottom
                      sx={{ mb: 0, mr: 0.5 }}
                    >
                      Логотип
                    </Typography>
                    <Tooltip title={watermarkTooltipText}>
                      <Info
                        size={16}
                        color="gray"
                        style={{ cursor: "pointer" }}
                      />
                    </Tooltip>
                  </Box>
                  <Box
                    sx={{
                      width: 80,
                      height: 80,
                      backgroundColor: "grey.200",
                      display: "flex",
                      alignItems: "center",
                      justifyContent: "center",
                      borderRadius: 1,
                      mb: 1,
                      cursor: mockSightData.watermark_lu
                        ? "pointer"
                        : "default", // Only clickable if there's an image
                      "&:hover": {
                        backgroundColor: mockSightData.watermark_lu
                          ? "grey.300"
                          : "grey.200",
                      },
                    }}
                    onClick={() =>
                      mockSightData.watermark_lu &&
                      handleSelectMedia("watermark_lu")
                    }
                  >
                    {mockSightData.watermark_lu ? (
                      <img
                        src={mockSightData.watermark_lu}
                        alt="Знак л.в"
                        style={{ maxWidth: "100%", maxHeight: "100%" }}
                      />
                    ) : (
                      <ImagePlus size={24} color="grey" />
                    )}
                  </Box>
                  <Button
                    variant="outlined"
                    size="small"
                    onClick={() => handleSelectMedia("watermark_lu")}
                  >
                    Выбрать
                  </Button>
                </Paper>
                <Paper
                  elevation={2}
                  sx={{
                    padding: 2,
                    display: "flex",
                    flexDirection: "column",
                    alignItems: "center",
                    gap: 1,
                    flex: 1,
                    minWidth: 150, // Ensure a minimum width
                  }}
                >
                  <Box sx={{ display: "flex", alignItems: "center" }}>
                    <Typography
                      variant="subtitle2"
                      gutterBottom
                      sx={{ mb: 0, mr: 0.5 }}
                    >
                      Водяной знак (л.в)
                    </Typography>
                    <Tooltip title={watermarkTooltipText}>
                      <Info
                        size={16}
                        color="gray"
                        style={{ cursor: "pointer" }}
                      />
                    </Tooltip>
                  </Box>
                  <Box
                    sx={{
                      width: 80,
                      height: 80,
                      backgroundColor: "grey.200",
                      display: "flex",
                      alignItems: "center",
                      justifyContent: "center",
                      borderRadius: 1,
                      mb: 1,
                      cursor: mockSightData.watermark_lu
                        ? "pointer"
                        : "default", // Only clickable if there's an image
                      "&:hover": {
                        backgroundColor: mockSightData.watermark_lu
                          ? "grey.300"
                          : "grey.200",
                      },
                    }}
                    onClick={() =>
                      mockSightData.watermark_lu &&
                      handleSelectMedia("watermark_lu")
                    }
                  >
                    {mockSightData.watermark_lu ? (
                      <img
                        src={mockSightData.watermark_lu}
                        alt="Знак л.в"
                        style={{ maxWidth: "100%", maxHeight: "100%" }}
                      />
                    ) : (
                      <ImagePlus size={24} color="grey" />
                    )}
                  </Box>
                  <Button
                    variant="outlined"
                    size="small"
                    onClick={() => handleSelectMedia("watermark_lu")}
                  >
                    Выбрать
                  </Button>
                </Paper>

                <Paper
                  elevation={2}
                  sx={{
                    padding: 2,
                    display: "flex",
                    flexDirection: "column",
                    alignItems: "center",
                    gap: 1,
                    flex: 1,
                    minWidth: 150, // Ensure a minimum width
                  }}
                >
                  <Box sx={{ display: "flex", alignItems: "center" }}>
                    <Typography
                      variant="subtitle2"
                      gutterBottom
                      sx={{ mb: 0, mr: 0.5 }}
                    >
                      Водяной знак (п.в)
                    </Typography>
                    <Tooltip title={watermarkTooltipText}>
                      <Info
                        size={16}
                        color="gray"
                        style={{ cursor: "pointer" }}
                      />
                    </Tooltip>
                  </Box>
                  <Box
                    sx={{
                      width: 80,
                      height: 80,
                      backgroundColor: "grey.200",
                      display: "flex",
                      alignItems: "center",
                      justifyContent: "center",
                      borderRadius: 1,
                      mb: 1,
                      cursor: mockSightData.watermark_rd
                        ? "pointer"
                        : "default", // Only clickable if there's an image
                      "&:hover": {
                        backgroundColor: mockSightData.watermark_rd
                          ? "grey.300"
                          : "grey.200",
                      },
                    }}
                    onClick={() =>
                      mockSightData.watermark_rd &&
                      handleSelectMedia("watermark_rd")
                    }
                  >
                    {mockSightData.watermark_rd ? (
                      <img
                        src={mockSightData.watermark_rd}
                        alt="Знак п.в"
                        style={{ maxWidth: "100%", maxHeight: "100%" }}
                      />
                    ) : (
                      <ImagePlus size={24} color="grey" />
                    )}
                  </Box>
                  <Button
                    variant="outlined"
                    size="small"
                    onClick={() => handleSelectMedia("watermark_rd")}
                  >
                    Выбрать
                  </Button>
                </Paper>
              </Box>
            </Box>
          </Box> */}

            {/* LanguageSwitcher positioned at the top right */}

            <LanguageSwitcher />

            {/* Save Button fixed at the bottom right */}
            <Box
              sx={{
                position: "absolute",
                bottom: 0,
                right: 0,
                padding: 2,
                backgroundColor: "background.paper", // To ensure it stands out over content
                width: "100%", // Take full width to cover content below it
                display: "flex",
                justifyContent: "flex-end", // Align to the right
              }}
            >
              <Button variant="contained" color="success" onClick={handleSave}>
                Сохранить
              </Button>
            </Box>
          </Box>
        </Box>
      </TabPanel>
    );
  }
);
