import { Box, Button, TextField, Paper, Typography } from "@mui/material";
import { BackButton, Sight, TabPanel } from "@shared";
import { ReactMarkdownComponent, ReactMarkdownEditor } from "@widgets";
import { Unlink, Trash2, ImagePlus } from "lucide-react";
import { useState } from "react";

export const LeftWidgetTab = ({
  value,
  index,
  data,
}: {
  value: number;
  index: number;
  data?: Sight;
}) => {
  const [articleTitle, setArticleTitle] = useState("");
  const [markdownContent, setMarkdownContent] = useState("");
  const [articleMedia, setArticleMedia] = useState<string | null>(null); // Для превью медиа

  const handleSelectMediaForArticle = () => {
    // Логика открытия модального окна для выбора медиа для статьи
    console.log("Select media fo  r left article");
    // Для примера, установим моковое изображение
    // setArticleMedia("https://via.placeholder.com/350x200.png?text=Article+Media");
  };

  const handleUnlinkArticle = () => {
    console.log("Unlink left article");
  };

  const handleDeleteArticle = () => {
    console.log("Delete left article");
  };

  const handleSave = () => {
    console.log("Saving left widget...");
  };

  return (
    <TabPanel value={value} index={index}>
      <Box
        sx={{
          display: "flex",
          flexDirection: "column",
          gap: 3,
          paddingBottom: "70px",
          position: "relative",
        }}
      >
        <BackButton />

        <Paper
          elevation={2}
          sx={{
            display: "flex",
            alignItems: "center",
            justifyContent: "space-between",
            paddingX: 2.5,
            paddingY: 1.5,
            borderRadius: 2,
            border: "1px solid",
            borderColor: "divider",
          }}
        >
          <Typography variant="h6">Левая статья</Typography>
          <Box sx={{ display: "flex", alignItems: "center", gap: 2 }}>
            <Button
              variant="outlined"
              color="primary"
              startIcon={<Unlink size={18} />}
              onClick={handleUnlinkArticle}
              size="small"
            >
              Открепить
            </Button>
            <Button
              variant="outlined"
              color="error"
              startIcon={<Trash2 size={18} />}
              onClick={handleDeleteArticle}
              size="small"
            >
              Удалить
            </Button>
          </Box>
        </Paper>

        <Box sx={{ display: "flex", gap: 3, flexGrow: 1 }}>
          {/* Левая колонка: Редактирование */}
          <Box
            sx={{ flex: 2, display: "flex", flexDirection: "column", gap: 2 }}
          >
            <TextField
              label="Название информации" // На макете "Название" для статьи, потом "Информация"
              value={articleTitle}
              onChange={(e) => setArticleTitle(e.target.value)}
              variant="outlined"
              sx={{ width: "100%" }} // Примерная ширина как на макете
            />

            <ReactMarkdownEditor
              value={markdownContent}
              onChange={setMarkdownContent}
            />

            {/* Блок МЕДИА для статьи */}
            <Paper elevation={1} sx={{ padding: 2, mt: 1 }}>
              <Typography variant="h6" gutterBottom>
                МЕДИА
              </Typography>
              {/* Здесь будет UI для управления медиа статьи */}
              {articleMedia ? (
                <Box sx={{ mb: 1 }}>
                  <img
                    src={articleMedia}
                    alt="Article media"
                    style={{
                      maxWidth: "100%",
                      maxHeight: "150px",
                      borderRadius: "4px",
                    }}
                  />
                </Box>
              ) : (
                <Box
                  sx={{
                    width: "100%",
                    height: 100,
                    backgroundColor: "grey.100",
                    display: "flex",
                    alignItems: "center",
                    justifyContent: "center",
                    borderRadius: 1,
                    mb: 1,
                    border: "2px dashed",
                  }}
                >
                  <Typography color="text.secondary">Нет медиа</Typography>
                </Box>
              )}
              <Button variant="contained" onClick={handleSelectMediaForArticle}>
                Выбрать/Загрузить медиа
              </Button>
            </Paper>
          </Box>

          {/* Правая колонка: Предпросмотр */}
          <Box sx={{ display: "flex", flexDirection: "column", gap: 1.5 }}>
            <Typography variant="h6">Предпросмотр</Typography>
            <Paper
              elevation={3}
              sx={{
                width: "100%", // Ширина как на макете ~350px
                minWidth: 320,
                maxWidth: 400,
                height: "auto", // Автоматическая высота или можно задать minHeight
                minHeight: 500,
                backgroundColor: "#877361", // Желтоватый фон
                overflowY: "auto",
                padding: 0,
                display: "flex",
                flexDirection: "column",
              }}
            >
              {/* Медиа в превью (если есть) */}
              {articleMedia && (
                <Box
                  sx={{
                    width: "100%",
                    height: 200,
                    backgroundColor: "grey.300",
                    display: "flex",
                    alignItems: "center",
                    justifyContent: "center",
                  }}
                >
                  <img
                    src={articleMedia}
                    alt="Превью медиа"
                    style={{
                      objectFit: "cover",
                      width: "100%",
                      height: "100%",
                    }}
                  />
                </Box>
              )}
              {!articleMedia && (
                <Box
                  sx={{
                    width: "100%",
                    height: 200,
                    backgroundColor: "grey.300",
                    display: "flex",
                    alignItems: "center",
                    justifyContent: "center",
                  }}
                >
                  <ImagePlus size={48} color="grey" />
                </Box>
              )}

              {/* Заголовок в превью */}
              <Box
                sx={{
                  backgroundColor: "#877361",
                  color: "white",
                  padding: 1.5,
                }}
              >
                <Typography
                  variant="h5"
                  component="h2"
                  sx={{ wordBreak: "break-word" }}
                >
                  {articleTitle || "Название информации"}
                </Typography>
              </Box>

              {/* Текст статьи в превью */}
              <Box
                sx={{
                  padding: 2,

                  flexGrow: 1,
                }}
              >
                <ReactMarkdownComponent value={markdownContent} />
              </Box>
            </Paper>
          </Box>
        </Box>

        <Box sx={{ position: "absolute", bottom: 0, right: 0, padding: 2 }}>
          <Button variant="contained" color="success" onClick={handleSave}>
            Сохранить
          </Button>
        </Box>
      </Box>
    </TabPanel>
  );
};
